@@ -1,5 +1,6 @@
 {-# LANGUAGE DeriveGeneric #-}
 -- | Simple English clause creation parameterized by individual words.
+-- See the tests for example texts generated.
 module NLP.Miniutter.English
   ( Part(..), Person(..), Polarity(..), Irregular(..)
   , makeSentence, makePhrase, defIrregular, (<+>)
@@ -413,6 +414,7 @@ defIrrPlural = Map.fromList $ concatMap generateCapitalized $
   , ("information", "information")
   , ("whiff",       "whiffs")
   , ("graffiti",    "graffiti")
+  , ("stomach",     "stomachs")
   ]
 
 generateCapitalized :: (Text, Text) -> [(Text, Text)]
